@@ -58,7 +58,6 @@
 #include <QMimeDatabase>
 #include <QMimeType>
 
-#include <memory>
 
 class ElisaApplicationPrivate
 {
@@ -67,7 +66,7 @@ public:
     explicit ElisaApplicationPrivate(QObject *parent)
 #if KF5XmlGui_FOUND
         : mCollection(parent)
-    #endif
+#endif
     {
         Q_UNUSED(parent)
     }
@@ -94,7 +93,7 @@ public:
 
     QFileSystemWatcher mConfigFileWatcher;
 
-    KColorSchemeManager *mSchemes;
+    KColorSchemeManager *mSchemes = nullptr;
 };
 
 ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::make_unique<ElisaApplicationPrivate>(this))
@@ -179,25 +178,25 @@ void ElisaApplication::setupActions(const QString &actionName)
     if (actionName == QLatin1String("Seek") && KAuthorized::authorizeAction(actionName)) {
             auto seekAction = d->mCollection.addAction(actionName, this, &ElisaApplication::seek);
             seekAction->setText(i18n("Seek forward 10 seconds"));
-            d->mCollection.setDefaultShortcut(seekAction, QKeySequence(Qt::SHIFT + Qt::Key_Right));
+            d->mCollection.setDefaultShortcut(seekAction, QKeySequence(Qt::SHIFT | Qt::Key_Right));
     }
 
     if (actionName == QLatin1String("Scrub") && KAuthorized::authorizeAction(actionName)) {
             auto scrubAction = d->mCollection.addAction(actionName, this, &ElisaApplication::scrub);
             scrubAction->setText(i18n("Scrub backwards 10 seconds"));
-            d->mCollection.setDefaultShortcut(scrubAction, QKeySequence(Qt::SHIFT + Qt::Key_Left));
+            d->mCollection.setDefaultShortcut(scrubAction, QKeySequence(Qt::SHIFT | Qt::Key_Left));
     }
 
     if (actionName == QLatin1String("NextTrack") && KAuthorized::authorizeAction(actionName)) {
             auto nextTrackAction = d->mCollection.addAction(actionName, this, &ElisaApplication::nextTrack);
             nextTrackAction->setText(i18n("Go to next track"));
-            d->mCollection.setDefaultShortcut(nextTrackAction, QKeySequence(Qt::CTRL + Qt::Key_Right));
+            d->mCollection.setDefaultShortcut(nextTrackAction, QKeySequence(Qt::CTRL | Qt::Key_Right));
     }
 
     if (actionName == QLatin1String("PreviousTrack") && KAuthorized::authorizeAction(actionName)) {
             auto previousTrackAction = d->mCollection.addAction(actionName, this, &ElisaApplication::previousTrack);
             previousTrackAction->setText(i18n("Go to previous track"));
-            d->mCollection.setDefaultShortcut(previousTrackAction, QKeySequence(Qt::CTRL + Qt::Key_Left));
+            d->mCollection.setDefaultShortcut(previousTrackAction, QKeySequence(Qt::CTRL | Qt::Key_Left));
     }
 
     if (actionName == QLatin1String("Play-Pause") && KAuthorized::authorizeAction(actionName)) {
