@@ -92,12 +92,15 @@ public:
                                                DataTypes::TitleRole,
                                                {DataTypes::TitleRole, DataTypes::AlbumRole, DataTypes::ArtistRole,
                                                 DataTypes::GenreRole, DataTypes::YearRole, DataTypes::DurationRole,
-                                                DataTypes::ComposerRole, DataTypes::LyricistRole},
+                                                DataTypes::ComposerRole, DataTypes::LyricistRole,
+                                                DataTypes::FileModificationTime},
                                                {i18n("Title"), i18n("Album"), i18n("Artist"), i18n("Genre"),
-                                                i18n("Year"), i18n("Duration"), i18n("Composer"), i18n("Lyricist")},
+                                                i18n("Year"), i18n("Duration"), i18n("Composer"), i18n("Lyricist"),
+                                                i18n("Last Modified")},
                                                Qt::AscendingOrder,
                                                {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"),
-                                                i18n("Oldest First"), i18n("Newest First"), i18n("Shortest First"), i18n("Longest First"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A")},
+                                                i18n("Oldest First"), i18n("Newest First"), i18n("Shortest First"), i18n("Longest First"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"),
+                                                i18n("Oldest First"), i18n("Newest First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
@@ -127,7 +130,7 @@ public:
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
                                                ViewManager::IsFlatModel,
-                                               QUrl::fromLocalFile(QDir::homePath())
+                                               QUrl::fromLocalFile(QDir::rootPath())
                                               },
                                               {{i18nc("Title of the file radios browser view", "Radio Stations")},
                                                QUrl{QStringLiteral("image://icon/radio")},
